/*
 * xstat - A statistics generator using GTK+
 *
 * Copyright (C) 2000 Julien Lesouef <julien.lesouef@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */


#include "Page.h"


/*
 * Constructs a page with a background image.
 */
Page::Page(char anImageDirectory[], char aBackground[], char aTitle[])
{
  strcpy(imageDirectory, anImageDirectory);
  strcpy(background, aBackground);
  strcpy(title, aTitle);
}


/*
 * Constructs a page with a background color.
 */
Page::Page(char aColor[], char aTitle[])
{
  strcpy(imageDirectory, "\0");
  strcpy(background, aColor);
  strcpy(title, aTitle);
}


/*
 * Gets the relative image directory.
 */
char *Page::getImageDirectory()
{
  return imageDirectory;
}


/*
 * Gets the background of the page.
 */
char *Page::getBackground()
{
  return background;
}


/*
 * Gets the title of the page.
 */
char *Page::getTitle()
{
  return title;
}


/*
 * Determines if the page has a background image.
 */
bool Page::hasImage()
{
  return (strcmp(imageDirectory, "\0"));
}


/*
 * Configures a page with a background image.
 */
void Page::configure(char anImageDirectory[], char aBackground[], char aTitle[])
{
  strcpy(imageDirectory, anImageDirectory);
  strcpy(background, aBackground);
  strcpy(title, aTitle);
}


/*
 * Configures a page with a background color.
 */
void Page::configure(char aColor[], char aTitle[])
{
  strcpy(imageDirectory, "\0");
  strcpy(background, aColor);
  strcpy(title, aTitle);
}


/*
 * Generates the head of the web page.
 */
void Page::makeHead(FILE *aFile, Log *log)
{
  struct tm adate;
  time_t atime;
  char *text = new char[100];

  fputs("<HTML>\n", aFile);

  fputs("<HEAD>\n", aFile);
  fputs("<META NAME=\"GENERATOR\" CONTENT=\"xstat\">\n", aFile);
  fputs("<TITLE>", aFile);
  fputs(title, aFile);
  fputs("</TITLE>\n", aFile);
  fputs("</HEAD>\n", aFile);

  fputs("<BODY ", aFile);
  if (!strcmp(imageDirectory, "\0"))
    {
      fputs("BGCOLOR=\"", aFile);
    }
  else
    {
      fputs("BACKGROUND=\"", aFile);
      fputs(imageDirectory, aFile);
    }
  fputs(background, aFile);
  fputs("\">\n", aFile);
  fputs("<CENTER><H1>", aFile);
  fputs(title, aFile);
  fputs("</H1>\n", aFile);
  fputs("<H5>", aFile);
  adate = log->getStartDate();
  fputs(asctime(&adate), aFile);
  fputs(" - ", aFile);
  adate = log->getEndDate();
  fputs(asctime(&adate), aFile);
  fputs("</H5>\n", aFile);
  fputs("<HR>\n", aFile);
}


/*
 * Generates the bottom of the web page.
 */
void Page::makeBottom(FILE *aFile)
{  
  struct tm *adate;
  time_t atime;

  fputs("Statistics generated with <A HREF=\"http://upsilon.free.fr/xstat/index.html\">xstat</A> on ", aFile);
  atime = time(NULL);
  adate = localtime(&atime);
  fputs(asctime(adate), aFile);
  fputs("<P>\n", aFile);
  fputs("Report bugs to <A HREF=\"mailto:julien.lesouef@free.fr\">Julien Lesouef</A>\n", aFile);
  fputs("</CENTER>\n", aFile);
  fputs("</BODY>\n", aFile);
  fputs("</HTML>\n", aFile);
}
