/*
 * xstat - A statistics generator using GTK+
 *
 * Copyright (C) 2000 Julien Lesouef <julien.lesouef@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */


#include <stdio.h>
#include "Config.h"


int main(int argc, char *argv[])
{
  Config *config;
  config = new Config();
  Log *log;
  log = new Log();
  FILE *file;
  int tmp;
  
  if (argc > 2) 
    {
      printf("Usage : statistic [file]\nfile : a xstat configuration file (default is $HOME/.xstat)\nPlease launch xstat to create this file\n");
      exit(-1);
    }
  if (argc == 1) tmp = config->loadCurrent();
  if (argc == 2) tmp = config->load(argv[1]);
  if (tmp == 0)
    {
      printf("The file does not exist.\n");
      exit(-1);
    }
  if (tmp == 1)
    {
      printf("The file is not a xstat configuration file.\n");
      exit(-1);
    }

  printf("Analysing log...\n");
  tmp = log->analyse(config->getLogName());
  if (tmp == -1) 
    {
      printf("The log file does not exist\n");
      exit(-1);
    }
  else if (tmp > 0)
    {
      printf("An error occured at line %i\n", tmp);
      exit(-1);
    }

  printf("Opening file %s...\n", config->getFileName());
  file = fopen(config->getFileName(), "w");
  if (file == NULL) 
    {
      printf("An error of file occured\n");
      exit(-1);
    }

  printf("Generating head of page...\n");
  config->getPage()->makeHead(file, log);

  for (int i = 0; i < config->getNbUsed(); i++)
    {
      printf("Generating %s...\n", config->getUsedStatName(i));
      config->getUsedStat(i)->generate(file, log);
    }
  
  printf("Generating bottom of page...\n");
  config->getPage()->makeBottom(file);
  fclose(file);
  printf("The web page has been generated\n");

  exit(0);
}
